Events
======

Asymptotic
----------
.. autoclass:: poisson_approval.Asymptotic
    :members:

Event
-----
.. autoclass:: poisson_approval.Event
    :members:

EventDuo
--------
.. autoclass:: poisson_approval.EventDuo
    :members:

EventPivotStrict
----------------
.. autoclass:: poisson_approval.EventPivotStrict
    :members:

EventPivotTij
-------------
.. autoclass:: poisson_approval.EventPivotTij
    :members:

EventPivotTjk
-------------
.. autoclass:: poisson_approval.EventPivotTjk
    :members:

EventPivotWeak
--------------
.. autoclass:: poisson_approval.EventPivotWeak
    :members:

EventTrio
---------
.. autoclass:: poisson_approval.EventTrio
    :members:

EventTrio1t
-----------
.. autoclass:: poisson_approval.EventTrio1t
    :members:

EventTrio2t
-----------
.. autoclass:: poisson_approval.EventTrio2t
    :members:
